@@ -1,4 +1,4 @@
-/*      $Id: events.c,v 1.277 2004/10/27 16:56:53 olivier Exp $
+/*      $Id: events.c,v 1.282 2004/11/04 21:51:38 olivier Exp $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -82,7 +82,7 @@ static int edge_scroll_x = 0;
 static int edge_scroll_y = 0;
 
 static void handleEvent (DisplayInfo *display_info, XEvent * ev);
-static void menu_callback (Menu * menu, MenuOp op, Window client_xwindow,
+static void menu_callback (Menu * menu, MenuOp op, Window xid,
     gpointer menu_data, gpointer item_data);
 static gboolean show_popup_cb (GtkWidget * widget, GdkEventButton * ev,
     gpointer data);
@@ -263,7 +263,7 @@ raise_cb (gpointer data)
     if (c)
     {
         clientRaise (c);
-        clientPassGrabButton1 (c);
+        clientPassGrabMouseButton (c);
     }
     return (TRUE);
 }
@@ -495,11 +495,11 @@ handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
                 break;
             case KEY_RAISE_WINDOW:
                 clientRaise (c);
-                clientPassGrabButton1 (NULL);
+                clientPassGrabMouseButton (NULL);
                 break;
             case KEY_LOWER_WINDOW:
                 clientLower (c);
-                clientPassGrabButton1 (NULL);
+                clientPassGrabMouseButton (NULL);
                 break;
             case KEY_TOGGLE_FULLSCREEN:
                 clientToggleFullscreen (c);
@@ -634,7 +634,7 @@ edgeButton (Client * c, int part, XButtonEvent * ev)
         if (tclick == XFWM_BUTTON_CLICK)
         {
             clientLower (c);
-            clientPassGrabButton1 (NULL);
+            clientPassGrabMouseButton (NULL);
         }
         else if (tclick != XFWM_BUTTON_UNDEFINED)
         {
@@ -650,7 +650,7 @@ edgeButton (Client * c, int part, XButtonEvent * ev)
                 clientSetFocus (c->screen_info, c, GDK_CURRENT_TIME, NO_FOCUS_FLAG);
             }
             clientRaise (c);
-            clientPassGrabButton1 (c);
+            clientPassGrabMouseButton (c);
         }
         if ((ev->button == Button1) || (ev->button == Button3))
         {
@@ -678,7 +678,7 @@ button1Action (Client * c, XButtonEvent * ev)
         clientSetFocus (screen_info, c, ev->time, NO_FOCUS_FLAG);
     }
     clientRaise (c);
-    clientPassGrabButton1 (c);
+    clientPassGrabMouseButton (c);
 
     memcpy(&copy_event, ev, sizeof(XEvent));
     tclick = typeOfClick (screen_info, c->window, &copy_event, TRUE);
@@ -728,7 +728,7 @@ titleButton (Client * c, int state, XButtonEvent * ev)
     else if (ev->button == Button2)
     {
         clientLower (c);
-        clientPassGrabButton1 (NULL);
+        clientPassGrabMouseButton (NULL);
     }
     else if (ev->button == Button3)
     {
@@ -756,7 +756,7 @@ titleButton (Client * c, int state, XButtonEvent * ev)
             if (screen_info->params->raise_on_click)
             {
                 clientRaise (c);
-                clientPassGrabButton1 (c);
+                clientPassGrabMouseButton (c);
             }
             ev->window = ev->root;
             if (screen_info->button_handler_id)
@@ -851,7 +851,7 @@ handleButtonPress (DisplayInfo *display_info, XButtonEvent * ev)
         else if ((ev->button == Button2) && (state == AltMask) && (screen_info->params->easy_click))
         {
             clientLower (c);
-            clientPassGrabButton1 (NULL);
+            clientPassGrabMouseButton (NULL);
         }
         else if ((ev->button == Button3) && (state == AltMask) && (screen_info->params->easy_click))
         {
@@ -883,7 +883,7 @@ handleButtonPress (DisplayInfo *display_info, XButtonEvent * ev)
                 if (screen_info->params->raise_on_click)
                 {
                     clientRaise (c);
-                    clientPassGrabButton1 (c);
+                    clientPassGrabMouseButton (c);
                 }
                 clientButtonPress (c, win, ev);
             }
@@ -920,7 +920,7 @@ handleButtonPress (DisplayInfo *display_info, XButtonEvent * ev)
                     if (screen_info->params->raise_on_click)
                     {
                         clientRaise (c);
-                        clientPassGrabButton1 (c);
+                        clientPassGrabMouseButton (c);
                     }
                     ev->window = ev->root;
                     if (screen_info->button_handler_id)
@@ -968,29 +968,23 @@ handleButtonPress (DisplayInfo *display_info, XButtonEvent * ev)
         {
             edgeButton (c, 4 + SIDE_RIGHT, ev);
         }
-        else
+        else if (ev->window == c->window)
         {
-            if (ev->button == Button1)
+            if ((screen_info->params->raise_with_any_button) || 
+                (ev->button == Button1))
             {
-                if (ev->window == c->window)
-                {
-                    clientPassGrabButton1 (c);
-                }
+                clientPassGrabMouseButton (c);
                 if (!(c->type & WINDOW_TYPE_DONT_FOCUS))
                 {
                     clientSetFocus (screen_info, c, ev->time, NO_FOCUS_FLAG);
                 }
-                if ((screen_info->params->raise_on_click) 
-                    || !FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_BORDER))
+                if ((screen_info->params->raise_on_click) || 
+                    !FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_BORDER))
                 {
                     clientRaise (c);
-                    clientPassGrabButton1 (c);
                 }
             }
-            if (ev->window == c->window)
-            {
-                replay = TRUE;
-            }
+            replay = TRUE;
         }
 
         if (replay)
@@ -1373,7 +1367,7 @@ handleConfigureRequest (DisplayInfo *display_info, XConfigureRequestEvent * ev)
         }
         if (ev->value_mask & CWStackMode)
         {
-            clientPassGrabButton1 (NULL);
+            clientPassGrabMouseButton (NULL);
         }
 #if 0
         /* Let's say that if the client performs a XRaiseWindow, we show the window if hidden */
@@ -1429,7 +1423,7 @@ handleEnterNotify (DisplayInfo *display_info, XCrossingEvent * ev)
                 clientSetFocus (c->screen_info, c, ev->time, FOCUS_FORCE);
                 if (!(screen_info->params->raise_on_click))
                 {
-                    clientPassGrabButton1 (c);
+                    clientPassGrabMouseButton (c);
                 }
             }
         }
@@ -1538,10 +1532,9 @@ handleFocusIn (DisplayInfo *display_info, XFocusChangeEvent * ev)
             (last_raised != NULL) && (c != last_raised))
         {
             clientRaise (c);
-            clientPassGrabButton1 (c);
+            clientPassGrabMouseButton (c);
         }
-        if ((screen_info->params->raise_on_focus) && 
-            !(screen_info->params->raise_on_click))
+        if (screen_info->params->raise_on_focus)
         {
             reset_timeout (screen_info);
         }
@@ -1590,7 +1583,7 @@ handleFocusOut (DisplayInfo *display_info, XFocusChangeEvent * ev)
         {
             TRACE ("focus lost from \"%s\" (0x%lx)", c->name, c->window);
             clientUpdateFocus (c->screen_info, NULL, NO_FOCUS_FLAG);
-            clientPassGrabButton1 (NULL);
+            clientPassGrabMouseButton (NULL);
             /* Clear timeout */
             clear_timeout ();
         }
@@ -1840,7 +1833,17 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
             clientShow (c, TRUE);
             clientRaise (c);
             clientSetFocus (screen_info, c, GDK_CURRENT_TIME, NO_FOCUS_FLAG);
-            clientPassGrabButton1 (c);
+            clientPassGrabMouseButton (c);
+        }
+        else if (ev->message_type == net_request_frame_extents)
+        {
+            TRACE ("client \"%s\" (0x%lx) has received a net_request_frame_extents event", c->name, c->window);
+            setNetFrameExtents (myScreenGetXDisplay (screen_info), 
+                                c->window, 
+                                frameTop (c),
+                                frameLeft (c),
+                                frameRight (c),
+                                frameBottom (c)); 
         }
     }
     else
@@ -1865,6 +1868,7 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
             if (ev->data.l[0] != screen_info->workspace_count)
             {
                 workspaceSetCount (screen_info, ev->data.l[0]);
+                getDesktopLayout(display_info->dpy, screen_info->xroot, screen_info->workspace_count, &screen_info->desktop_layout);
             }
         }
         else if ((ev->message_type == net_system_tray_manager) && (ev->data.l[1] == screen_info->net_system_tray_selection)  && (ev->format == 32))
@@ -1879,6 +1883,17 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
             clientToggleShowDesktop (screen_info, ev->data.l[0]);
             setHint (display_info->dpy, screen_info->xroot, net_showing_desktop, ev->data.l[0]);
         }
+        else if (ev->message_type == net_request_frame_extents)
+        {
+            TRACE ("window (0x%lx) has received a net_request_frame_extents event", c->name, ev->window);
+            /* Size estimate from the decoration extents */
+            setNetFrameExtents (myScreenGetXDisplay (screen_info), 
+                                ev->window, 
+                                frameDecorationTop (screen_info),
+                                frameDecorationLeft (screen_info),
+                                frameDecorationRight (screen_info),
+                                frameDecorationBottom (screen_info));
+        }
         else
         {
             TRACE ("unidentified client message for window 0x%lx", ev->window);
@@ -2017,7 +2032,7 @@ xfwm4_event_filter (XEvent * xevent, gpointer data)
 /* GTK specific stuff */
 
 static void
-menu_callback (Menu * menu, MenuOp op, Window client_xwindow, gpointer menu_data, gpointer item_data)
+menu_callback (Menu * menu, MenuOp op, Window xid, gpointer menu_data, gpointer item_data)
 {
     Client *c = NULL;
 
@@ -2028,71 +2043,75 @@ menu_callback (Menu * menu, MenuOp op, Window client_xwindow, gpointer menu_data
         xfwmWindowDelete (&menu_event_window);
     }
 
-    if (menu_data)
+    if ((menu_data != NULL) && (xid != None))
     {
-        c = (Client *) menu_data;
-        if (!c)
-        {
-            menu_free (menu);
-            return;
-        }
-        c->button_pressed[MENU_BUTTON] = FALSE;
+        ScreenInfo *screen_info = (ScreenInfo *) menu_data;
+        c = clientGetFromWindow (screen_info, xid, WINDOW);
     }
 
-    switch (op)
+    if (c)
     {
-        case MENU_OP_QUIT:
-            gtk_main_quit ();
-            break;
-        case MENU_OP_MAXIMIZE:
-        case MENU_OP_UNMAXIMIZE:
-            if (CLIENT_CAN_MAXIMIZE_WINDOW (c))
-            {
-                clientToggleMaximized (c, WIN_STATE_MAXIMIZED);
-            }
-            break;
-        case MENU_OP_MINIMIZE:
-            if (CLIENT_CAN_HIDE_WINDOW (c))
-            {
-                clientHide (c, c->win_workspace, TRUE);
-            }
-            frameDraw (c, FALSE, FALSE);
-            break;
-        case MENU_OP_MINIMIZE_ALL:
-            clientHideAll (c, c->win_workspace);
-            frameDraw (c, FALSE, FALSE);
-            break;
-        case MENU_OP_UNMINIMIZE:
-            clientShow (c, TRUE);
-            break;
-        case MENU_OP_SHADE:
-        case MENU_OP_UNSHADE:
-            clientToggleShaded (c);
-            break;
-        case MENU_OP_STICK:
-        case MENU_OP_UNSTICK:
-            clientToggleSticky (c, TRUE);
-            frameDraw (c, FALSE, FALSE);
-            break;
-        case MENU_OP_WORKSPACES:
-            clientSetWorkspace (c, GPOINTER_TO_INT (item_data), TRUE);
-            frameDraw (c, FALSE, FALSE);
-            break;
-        case MENU_OP_DELETE:
-            frameDraw (c, FALSE, FALSE);
-            clientClose (c);
-            break;
-        case MENU_OP_CONTEXT_HELP:
-            clientEnterContextMenuState (c);
-            frameDraw (c, FALSE, FALSE);
-            break;
-        case MENU_OP_ABOVE:
-        case MENU_OP_NORMAL:
-            clientToggleAbove (c);
-            /* Fall thru */
-        default:
-            frameDraw (c, FALSE, FALSE);
-            break;
+        c->button_pressed[MENU_BUTTON] = FALSE;
+
+        switch (op)
+        {
+            case MENU_OP_QUIT:
+                gtk_main_quit ();
+                break;
+            case MENU_OP_MAXIMIZE:
+            case MENU_OP_UNMAXIMIZE:
+                if (CLIENT_CAN_MAXIMIZE_WINDOW (c))
+                {
+                    clientToggleMaximized (c, WIN_STATE_MAXIMIZED);
+                }
+                break;
+            case MENU_OP_MINIMIZE:
+                if (CLIENT_CAN_HIDE_WINDOW (c))
+                {
+                    clientHide (c, c->win_workspace, TRUE);
+                }
+                frameDraw (c, FALSE, FALSE);
+                break;
+            case MENU_OP_MINIMIZE_ALL:
+                clientHideAll (c, c->win_workspace);
+                frameDraw (c, FALSE, FALSE);
+                break;
+            case MENU_OP_UNMINIMIZE:
+                clientShow (c, TRUE);
+                break;
+            case MENU_OP_SHADE:
+            case MENU_OP_UNSHADE:
+                clientToggleShaded (c);
+                break;
+            case MENU_OP_STICK:
+            case MENU_OP_UNSTICK:
+                clientToggleSticky (c, TRUE);
+                frameDraw (c, FALSE, FALSE);
+                break;
+            case MENU_OP_WORKSPACES:
+                clientSetWorkspace (c, GPOINTER_TO_INT (item_data), TRUE);
+                frameDraw (c, FALSE, FALSE);
+                break;
+            case MENU_OP_DELETE:
+                frameDraw (c, FALSE, FALSE);
+                clientClose (c);
+                break;
+            case MENU_OP_CONTEXT_HELP:
+                clientEnterContextMenuState (c);
+                frameDraw (c, FALSE, FALSE);
+                break;
+            case MENU_OP_ABOVE:
+            case MENU_OP_NORMAL:
+                clientToggleAbove (c);
+                /* Fall thru */
+            default:
+                frameDraw (c, FALSE, FALSE);
+                break;
+        }
+    }
+    else
+    {
+        gdk_beep ();
     }
     menu_free (menu);
 }
@@ -2259,10 +2278,10 @@ show_popup_cb (GtkWidget * widget, GdkEventButton * ev, gpointer data)
                               gdk_screen_get_height (screen_info->gscr), 
                               NoEventMask);
 
-    menu = menu_default (screen_info->gscr, ops, insensitive, menu_callback, 
+    menu = menu_default (screen_info->gscr, c->window, ops, insensitive, menu_callback, 
                          c->win_workspace, screen_info->workspace_count, 
                          screen_info->workspace_names, screen_info->workspace_names_length,
-                         display_info->xfilter, c);
+                         display_info->xfilter, screen_info);
 
     if (!menu_popup (menu, x, y, ev->button, ev->time))
     {
