@@ -1,4 +1,4 @@
-/*      $Id: hints.h,v 1.53 2004/10/06 21:56:44 olivier Exp $
+/*      $Id: hints.h,v 1.54 2004/11/03 15:15:02 olivier Exp $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -168,10 +168,12 @@ extern Atom net_client_list_stacking;
 extern Atom net_close_window;
 extern Atom net_current_desktop;
 extern Atom net_desktop_geometry;
-extern Atom net_desktop_viewport;
-extern Atom net_desktop_names;
 extern Atom net_desktop_layout;
+extern Atom net_desktop_names;
+extern Atom net_desktop_viewport;
+extern Atom net_frame_extents;
 extern Atom net_number_of_desktops;
+extern Atom net_request_frame_extents;
 extern Atom net_showing_desktop;
 extern Atom net_startup_id;
 extern Atom net_supported;
@@ -191,9 +193,11 @@ extern Atom net_wm_icon_geometry;
 extern Atom net_wm_icon_name;
 extern Atom net_wm_moveresize;
 extern Atom net_wm_name;
+extern Atom net_wm_opacity;
 extern Atom net_wm_state;
 extern Atom net_wm_state_above;
 extern Atom net_wm_state_below;
+extern Atom net_wm_state_demands_attention;
 extern Atom net_wm_state_fullscreen;
 extern Atom net_wm_state_hidden;
 extern Atom net_wm_state_maximized_horz;
@@ -203,9 +207,9 @@ extern Atom net_wm_state_shaded;
 extern Atom net_wm_state_skip_pager;
 extern Atom net_wm_state_skip_taskbar;
 extern Atom net_wm_state_sticky;
-extern Atom net_wm_state_demands_attention;
 extern Atom net_wm_strut;
 extern Atom net_wm_strut_partial;
+extern Atom net_wm_user_time;
 extern Atom net_wm_window_type;
 extern Atom net_wm_window_type_desktop;
 extern Atom net_wm_window_type_dialog;
@@ -215,8 +219,6 @@ extern Atom net_wm_window_type_normal;
 extern Atom net_wm_window_type_splash;
 extern Atom net_wm_window_type_toolbar;
 extern Atom net_wm_window_type_utility;
-extern Atom net_wm_user_time;
-extern Atom net_wm_opacity;
 extern Atom net_workarea;
 
 /* KDE extension */
@@ -254,6 +256,7 @@ void setNetSupportedHint (Display *, int, Window);
 gboolean getAtomList (Display *, Window, Atom, Atom **, int *);
 gboolean getCardinalList (Display *, Window, Atom, unsigned long **, int *);
 void setNetWorkarea (Display *, int, int, int, int, int *);
+void setNetFrameExtents (Display *, Window, int, int, int, int);
 void initNetDesktopInfo (Display *, int, int, int, int);
 void set_utf8_string_hint (Display *, Window, Atom, const char *);
 void getTransientFor (Display *, int, Window, Window *);
