@@ -1,4 +1,4 @@
-/*      $Id: main.c,v 1.119 2004/10/24 13:32:37 olivier Exp $
+/*      $Id: main.c,v 1.120 2004/11/01 15:50:24 olivier Exp $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -55,6 +55,7 @@
 #include "mywindow.h"
 #include "session.h"
 #include "startup_notification.h"
+#include "compositor.h"
 #include "spinning_cursor.h"
 
 #define BASE_EVENT_MASK \
@@ -321,7 +322,7 @@ print_version (void)
 static gint
 parse_compositor (const gchar *s)
 {
-    gchar *buffer, *rvalue;
+    gchar *rvalue;
     gboolean retval = 2;
 
     rvalue = strrchr (s, '=');
