@@ -1,4 +1,5 @@
-/* 
+/*      $Id: session.h,v 1.10 2004/08/22 22:18:50 olivier Exp $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
         the Free Software Foundation; either version 2, or (at your option)
@@ -13,20 +14,22 @@
         along with this program; if not, write to the Free Software
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
-        xfwm4    - (c) 2003 Olivier Fourdan
- 
+        xfwm4    - (c) 2002-2004 Olivier Fourdan
  */
 
+
 #ifndef INC_SESSION_H
 #define INC_SESSION_H
 
 #include <glib.h>
 #include "client.h"
+#include "display.h"
+#include "screen.h"
 
 /*
 **  Save window states to file which name is given in argument.
 */
-gboolean sessionSaveWindowStates (gchar *);
+gboolean sessionSaveWindowStates (DisplayInfo *, gchar *);
 
 /*
 **  Load window states to file which name is given in argument.
