@@ -1,4 +1,4 @@
-/*      $Id: settings.c,v 1.115 2004/10/24 13:32:37 olivier Exp $
+/*      $Id: settings.c,v 1.117 2004/11/06 13:02:11 olivier Exp $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -166,7 +166,12 @@ notify_cb (const char *name, const char *channel_name, McsAction action, McsSett
                     else if (!strcmp (name, "Xfwm/RaiseOnClick"))
                     {
                         screen_info->params->raise_on_click = setting->data.v_int;
-                        clientPassGrabButton1 (NULL);
+                        clientPassGrabMouseButton (NULL);
+                    }
+                    else if (!strcmp (name, "Xfwm/RaiseWithAnyButton"))
+                    {
+                        screen_info->params->raise_with_any_button = setting->data.v_int;
+                        clientPassGrabMouseButton (NULL);
                     }
                     else if (!strcmp (name, "Xfwm/SnapToBorder"))
                     {
@@ -180,6 +185,10 @@ notify_cb (const char *name, const char *channel_name, McsAction action, McsSett
                     {
                         screen_info->params->snap_width = setting->data.v_int;
                     }
+                    else if (!strcmp (name, "Xfwm/ToggleWorkspaces"))
+                    {
+                        screen_info->params->toggle_workspaces = setting->data.v_int;
+                    }
                     else if (!strcmp (name, "Xfwm/WrapWorkspaces"))
                     {
                         screen_info->params->wrap_workspaces = setting->data.v_int;
@@ -433,6 +442,12 @@ loadMcsData (ScreenInfo *screen_info, Settings rc[])
             setBooleanValueFromInt ("raise_on_click", setting->data.v_int, rc);
             mcs_setting_free (setting);
         }
+        if (mcs_client_get_setting (screen_info->mcs_client, "Xfwm/RaiseWithAnyButton", CHANNEL1,
+                &setting) == MCS_SUCCESS)
+        {
+            setBooleanValueFromInt ("raise_with_any_button", setting->data.v_int, rc);
+            mcs_setting_free (setting);
+        }
         if (mcs_client_get_setting (screen_info->mcs_client, "Xfwm/SnapToBorder", CHANNEL1,
                 &setting) == MCS_SUCCESS)
         {
@@ -458,6 +473,12 @@ loadMcsData (ScreenInfo *screen_info, Settings rc[])
             setBooleanValueFromInt ("wrap_workspaces", setting->data.v_int, rc);
             mcs_setting_free (setting);
         }
+        if (mcs_client_get_setting (screen_info->mcs_client, "Xfwm/ToggleWorkspaces", CHANNEL1,
+                &setting) == MCS_SUCCESS)
+        {
+            setBooleanValueFromInt ("toggle_workspaces", setting->data.v_int, rc);
+            mcs_setting_free (setting);
+        }
         if (mcs_client_get_setting (screen_info->mcs_client, "Xfwm/WrapWindows", CHANNEL1,
                 &setting) == MCS_SUCCESS)
         {
@@ -1051,6 +1072,7 @@ loadSettings (ScreenInfo *screen_info)
         {"raise_delay", NULL, TRUE},
         {"raise_on_click", NULL, TRUE},
         {"raise_on_focus", NULL, TRUE},
+        {"raise_with_any_button", NULL, TRUE},
         {"snap_to_border", NULL, TRUE},
         {"snap_to_windows", NULL, TRUE},
         {"snap_width", NULL, TRUE},
@@ -1072,6 +1094,7 @@ loadSettings (ScreenInfo *screen_info)
         {"wrap_layout", NULL, TRUE},
         {"wrap_cycle", NULL, TRUE},
         {"scroll_workspaces", NULL, TRUE},
+        {"toggle_workspaces", NULL, TRUE},
         {"wrap_resistance", NULL, TRUE},
         /* Keys */
         {"add_workspace_key", NULL, TRUE},
@@ -1183,6 +1206,8 @@ loadSettings (ScreenInfo *screen_info)
     screen_info->params->raise_delay = abs (TOINT (getValue ("raise_delay", rc)));
     screen_info->params->raise_on_click =
         !g_ascii_strcasecmp ("true", getValue ("raise_on_click", rc));
+    screen_info->params->raise_with_any_button =
+        !g_ascii_strcasecmp ("true", getValue ("raise_with_any_button", rc));
 
     screen_info->params->snap_to_border =
         !g_ascii_strcasecmp ("true", getValue ("snap_to_border", rc));
@@ -1223,6 +1248,8 @@ loadSettings (ScreenInfo *screen_info)
         workspaceSetCount (screen_info, workspace_count);
     }
 
+    screen_info->params->toggle_workspaces =
+        !g_ascii_strcasecmp ("true", getValue ("toggle_workspaces", rc));
     screen_info->params->wrap_workspaces =
         !g_ascii_strcasecmp ("true", getValue ("wrap_workspaces", rc));
     screen_info->params->wrap_layout =
