@@ -1,4 +1,4 @@
-/*      $Id: settings.h,v 1.40 2004/09/08 15:59:31 olivier Exp $
+/*      $Id: settings.h,v 1.47 2004/11/06 13:02:11 olivier Exp $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 #include "screen.h"
 #include "keyboard.h"
 #include "mypixmap.h"
+#include "hints.h"
 
 #ifndef INC_SETTINGS_H
 #define INC_SETTINGS_H
@@ -107,7 +108,15 @@
 #define KEY_LOWER_WINDOW                50
 #define KEY_RAISE_WINDOW                51
 #define KEY_TOGGLE_FULLSCREEN           52
-#define KEY_COUNT                       53
+#define KEY_UP_WORKSPACE                53
+#define KEY_DOWN_WORKSPACE              54
+#define KEY_LEFT_WORKSPACE              55
+#define KEY_RIGHT_WORKSPACE             56
+#define KEY_MOVE_UP_WORKSPACE           57
+#define KEY_MOVE_DOWN_WORKSPACE         58
+#define KEY_MOVE_LEFT_WORKSPACE         59
+#define KEY_MOVE_RIGHT_WORKSPACE        60
+#define KEY_COUNT                       61
 #define NB_KEY_SHORTCUTS                10
 
 #define ALIGN_LEFT                      0
@@ -144,27 +153,37 @@ struct _XfwmParams
     int double_click_action;
     int raise_delay;
     int snap_width;
+    int shadow_delta_x;
+    int shadow_delta_y;
+    int shadow_delta_width;
+    int shadow_delta_height;
     int title_alignment;
     int title_horizontal_offset;
     int wrap_resistance;
     gboolean title_shadow[2];
-    gboolean cycle_hidden;
-    gboolean cycle_minimum;
     gboolean box_move;
     gboolean box_resize;
     gboolean click_to_focus;
+    gboolean cycle_hidden;
+    gboolean cycle_minimum;
     gboolean easy_click;
     gboolean focus_hint;
     gboolean focus_new;
     gboolean full_width_title;
+    gboolean prevent_focus_stealing;
     gboolean raise_on_click;
     gboolean raise_on_focus;
+    gboolean raise_with_any_button;
+    gboolean scroll_workspaces;
     gboolean snap_to_border;
     gboolean snap_to_windows;
     gboolean title_vertical_offset_active;
     gboolean title_vertical_offset_inactive;
-    gboolean wrap_workspaces;
+    gboolean toggle_workspaces;
+    gboolean wrap_cycle;
+    gboolean wrap_layout;
     gboolean wrap_windows;
+    gboolean wrap_workspaces;
 };
 
 gboolean loadSettings   (ScreenInfo *);
