@@ -1,4 +1,4 @@
-/*      $Id: workspaces.c,v 1.85 2004/10/23 13:14:27 olivier Exp $
+/*      $Id: workspaces.c,v 1.88 2004/11/06 13:04:03 olivier Exp $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -73,6 +73,8 @@ workspaceGetPosition (ScreenInfo *screen_info, int n, int * row, int * col)
             *col = major_length - *col - 1;
             *row = minor_length - *row - 1;
             break;
+        default:
+            break;
     }
 
     if (l->orientation == NET_WM_ORIENTATION_VERT)
@@ -129,6 +131,8 @@ workspaceGetNumber (ScreenInfo *screen_info, int row, int col)
             col = major_length - col - 1;
             row = minor_length - row - 1;
             break;
+        default:
+            break;
     }
 
     n = row*major_length + col;
@@ -235,6 +239,16 @@ workspaceSwitch (ScreenInfo *screen_info, int new_ws, Client * c2)
 
     TRACE ("entering workspaceSwitch");
 
+    if ((new_ws == screen_info->current_ws) && (screen_info->params->toggle_workspaces))
+    {
+        new_ws = screen_info->previous_ws;
+    }
+
+    if (new_ws == screen_info->current_ws)
+    {
+        return;
+    }
+
     if (screen_info->params->wrap_cycle)
     {
         if (new_ws > screen_info->workspace_count - 1)
@@ -259,10 +273,6 @@ workspaceSwitch (ScreenInfo *screen_info, int new_ws, Client * c2)
                       GrabModeAsync, None, None, GDK_CURRENT_TIME);
     }
     
-    if (new_ws == screen_info->current_ws)
-    {
-         new_ws = screen_info->previous_ws;
-    }
     screen_info->previous_ws = screen_info->current_ws;
     screen_info->current_ws = new_ws;
     if (c2)
@@ -415,6 +425,9 @@ workspaceSetCount (ScreenInfo * screen_info, int count)
                          gdk_screen_get_width (screen_info->gscr),
                          gdk_screen_get_height (screen_info->gscr),
                          screen_info->margins);
+    /* Recompute the layout based on the (changed) number of desktops */
+    getDesktopLayout(myScreenGetXDisplay (screen_info), screen_info->xroot, screen_info->workspace_count, 
+                         &screen_info->desktop_layout);
 }
 
 void
